0.9.9 API documentation: quaternion_trigonometric.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

quaternion_trigonometric.hpp
Go to the documentation of this file.
1
18 #pragma once
19
20 // Dependency:
21 #include "../trigonometric.hpp"
22 #include "../exponential.hpp"
23 #include "scalar_constants.hpp"
24 #include "vector_relational.hpp"
25 #include <limits>
26
27 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
28 # pragma message("GLM: GLM_EXT_quaternion_trigonometric extension included")
29 #endif
30
31 namespace glm
32 {
35
40 template<typename T, qualifier Q>
41 GLM_FUNC_DECL T angle(qua<T, Q> const& x);
42
47 template<typename T, qualifier Q>
48 GLM_FUNC_DECL vec<3, T, Q> axis(qua<T, Q> const& x);
49
57 template<typename T, qualifier Q>
58 GLM_FUNC_DECL qua<T, Q> angleAxis(T const& angle, vec<3, T, Q> const& axis);
59
61 } //namespace glm
62
63 #include "quaternion_trigonometric.inl"
vector_relational.hpp
GLM_EXT_vector_relational
glm::angle
GLM_FUNC_DECL T angle(qua< T, Q > const &x)
Returns the quaternion rotation angle.
glm::angleAxis
GLM_FUNC_DECL qua< T, Q > angleAxis(T const &angle, vec< 3, T, Q > const &axis)
Build a quaternion from an angle and a normalized axis.
scalar_constants.hpp
GLM_EXT_scalar_constants
glm::axis
GLM_FUNC_DECL vec< 3, T, Q > axis(qua< T, Q > const &x)
Returns the q rotation axis.
glm
Definition: common.hpp:20